summaryrefslogtreecommitdiff
path: root/libs/ardour/ardour/element_importer.h
diff options
context:
space:
mode:
Diffstat (limited to 'libs/ardour/ardour/element_importer.h')
-rw-r--r--libs/ardour/ardour/element_importer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libs/ardour/ardour/element_importer.h b/libs/ardour/ardour/element_importer.h
index 9d2d9cc0de..396ac8358d 100644
--- a/libs/ardour/ardour/element_importer.h
+++ b/libs/ardour/ardour/element_importer.h
@@ -110,8 +110,8 @@ class ElementImporter
/// The sample rate of the session from which we are importing
nframes_t sample_rate;
- /// Converts smpte time to a string
- std::string smpte_to_string (SMPTE::Time & time) const;
+ /// Converts timecode time to a string
+ std::string timecode_to_string (Timecode::Time & time) const;
/// Converts samples so that times match the sessions sample rate
nframes_t rate_convert_samples (nframes_t samples) const;